@@ -2,11 +2,11 @@ package Test2::Event::Bail;
 use strict;
 use warnings;
 
-our $VERSION = '1.302079'; # TRIAL
+our $VERSION = '1.302080'; # TRIAL
 
 
 BEGIN { require Test2::Event; our @ISA = qw(Test2::Event) }
-use Test2::Util::HashBase qw{reason};
+use Test2::Util::HashBase qw{reason buffered};
 
 sub callback {
     my $self = shift;
@@ -92,7 +92,7 @@ F<http://github.com/Test-More/test-more/>.
 
 =head1 COPYRIGHT
 
-Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2017 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
