@@ -3,7 +3,7 @@ use strict;
 use warnings;
 require PerlIO;
 
-our $VERSION = '1.302079'; # TRIAL
+our $VERSION = '1.302080'; # TRIAL
 
 use Test2::Util::HashBase qw{
     no_numbers handles _encoding last_fh
@@ -242,7 +242,7 @@ sub event_bail {
     my $self = shift;
     my ($e, $num) = @_;
 
-    return if $e->nested;
+    return if $e->nested && !$e->buffered;
 
     return [
         OUT_STD,
@@ -536,7 +536,7 @@ F<http://github.com/Test-More/test-more/>.
 
 =head1 COPYRIGHT
 
-Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2017 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
